@@ -33,11 +33,11 @@ usage:
 def get_file_text(filename):
     if isinstance(filename, str):
         try:
-            fp = open(os.path.join(path, filename), 'rb')
+            fp = open(os.path.join(template_path, filename), 'rb')
             text = fp.read()
             fp.close()
         except IOError:
-            raise RestrictedError(filename, '', 'Unable to find the file')
+            raise Exception(filename, '', 'Unable to find the file')
     else:
         text = filename.read()
     return text
@@ -47,7 +47,7 @@ def process(filein=False, bitsin=False, parsed=False):
         bitsin = get_file_text(filein)
     if not filein and not bitsin:
         bitsin = sys.stdin.read()
-    parser = wemplate.TemplateParser(bitsin,path=path)
+    parser = wemplate.TemplateParser(bitsin,path=template_path)
                                 
     return str(parser) if parsed else parser.render()
     
@@ -57,6 +57,9 @@ def start():
     This function simply 
     """
     want_parsed = False
+    global template_path
+    global pwd
+    template_path = os.path.abspath('.')
     try:
         opciones, input_files = getopt.getopt(sys.argv[1:], "p:hx?",
                                         ["help", "version"])
@@ -66,8 +69,7 @@ def start():
         sys.exit(2)
     for o, a in opciones: #process the options supplied on the command line
         if o == "-p":
-            global path
-            path = os.path.abspath(a)
+            template_path = os.path.abspath(a)
         elif o == "-x":
             want_parsed = True
         elif o in ("-?", "-h", "--help"):
@@ -80,8 +82,5 @@ def start():
     else:
         sys.stdout.write(process(bitsin=sys.stdin.read(), parsed=want_parsed))
         
-global path 
-path = os.getcwd()
-
 if __name__ == "__main__" :
     start()
